#' @name met
#' @title Metabolite table
#' @description This data frame contains the metabolite definition of 112 metabolites according to the cols of \link{raw}.
#' @docType data
#' @author Jan Lisec \email{jan.lisec@@charite.de}
#' @references \url{http://dx.doi.org/10.1111/j.1365-313X.2011.04689.x}
#' @keywords data
"met"
